@@ -14,7 +14,6 @@
 
 
 void gibbsOneSample(double *y, int N, double rscale, int iterations, double *chains, int doInterval, double *interval, int progress, SEXP pBar, SEXP callback, SEXP rho);
-
 void gibbsOneWayAnova(double *y, int *N, int J, int sumN, int *whichJ, double rscale, int iterations, double *chains, double *CMDE, SEXP debug, int progress, SEXP pBar, SEXP callback, SEXP rho);
 
 double sampleSig2EqVar(double sig2, double *mu, double tau, double *yBar, double *SS, int *N, int sumN, int J, double sdMetrop, double *acc);
@@ -28,27 +27,13 @@ double jeffSamplerNwayAov(double *samples, double *gsamples, int iters, double *
 SEXP RimportanceSamplerNwayAov(SEXP Riters, SEXP RXtCX, SEXP RpriorX, SEXP RXtCy, SEXP RytCy, SEXP RN, SEXP RP, SEXP RnGs, SEXP RgMap, SEXP Ra, SEXP Rb, SEXP Rmu, SEXP Rsig, SEXP RincCont, SEXP progressR, SEXP pBar, SEXP callback, SEXP rho);
 double importanceSamplerNwayAov(double *samples, double *gsamples, int iters, double *XtCX, double *priorX, double *XtCy, double ytCy, int N, int P,int nGs, int *gMap, double *a, double *b, double *mu, double *sig, int incCont, int *badSamples, int progress, SEXP pBar, SEXP callback, SEXP rho);
 
-
-SEXP RLogMeanExpLogs(SEXP Rv, SEXP Rlen);
-
-SEXP RLogCumMeanExpLogs(SEXP Rv, SEXP Rlen);
-void logCumMeanExpLogs(double *v, int len, double *ret);
-
-
-double logSumExpLogs(double *v, int len);
-
-double logMeanExpLogs(double *v, int len);
-
 double LogOnePlusExpX(double x);
-
 double LogOnePlusX(double x);
 
 double quadform(double *x, double *A, int N, int incx, int LDA);
-
 double quadform2(double *x, double *A, int N, int incx, int LDA);
 
 SEXP rmvGaussianR(SEXP mu, SEXP Sigma);
-
 void rmvGaussianC(double *mu, double *Sigma, int p);
 
 int InvMatrixUpper(double *A, int p);
@@ -56,15 +41,12 @@ int InvMatrixUpper(double *A, int p);
 double matrixDet(double *A, int N, int LDA, int doLog, int *info);
 
 void debugPrintMatrix(double *X, int rows, int cols);
-
 void debugPrintVector(double *x, int len);
 
 void GibbsNwayAov(double *chains, int iters, double *y, double *X, double *XtX, double *priorX, double *Xty, int N, int P, int nGs, int *gMap, double *r, int incCont, int *ignoreCols, int nOutputPars, int thin, int progress, SEXP pBar, SEXP callback, SEXP rho);
-
 SEXP RGibbsNwayAov(SEXP Riters, SEXP Ry, SEXP RX, SEXP RXtX, SEXP RpriorX, SEXP RXty, SEXP RN, SEXP RP, SEXP RnGs, SEXP RgMap, SEXP Rr, SEXP RincCont, SEXP RignoreCols, SEXP Rthin, SEXP progressR, SEXP pBar, SEXP callback, SEXP rho);
 
 SEXP RGibbsLinearReg(SEXP Riters, SEXP RCny, SEXP RX, SEXP RXtX, SEXP RXtCnX, SEXP RXtCny, SEXP RN, SEXP RP, SEXP Rr, SEXP sig2start, SEXP progressR, SEXP pBar, SEXP callback, SEXP rho);
-
 void GibbsLinearReg(double *chains, int iters, double *Cny, double *X, double *XtX, double *XtCnX, double *XtCny, int N, int P, double r, double sig2start, int progress, SEXP pBar, SEXP callback, SEXP rho);
 
 
